@@ -3,30 +3,40 @@ OC.L10N.register(
     {
     "Bookmarks" : "Zaznamki",
     "Add a Bookmark" : "Dodaj zaznamek",
+    "Add folder" : "Dodaj mapo",
     "Select" : "Izbor",
     "Deselect" : "Odstrani izbor",
     "Details" : "Podrobnosti",
     "Delete" : "Izbriši",
     "Saved" : "Shranjeno",
+    "Date added" : "Dodan je datum",
+    "Link" : "Povezava",
     "Tags" : "Oznake",
     "Description" : "Opis",
     "No bookmarks here." : "Ni še dodanih zaznamkov.",
+    "Favorites" : "Priljubljeno",
     "Settings" : "Nastavitve",
     "Add to {instanceName} " : "Dodaj {instanceName} ",
     "Recently added" : "Nedavno dodano",
     "Most visited" : "Najpogosteje obiskano",
+    "View mode" : "Način pogleda",
+    "List view" : "Seznamski pogled",
     "RSS Feed" : "Vir RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Trajno odstrani vse zaznamke, povezane z računom. Dejanja ni mogoče povrniti!",
     "Delete all bookmarks" : "Izbriši vse zaznamke",
     "Open details" : "Odpri podrobnosti",
     "An error occurred while trying to save the bookmark." : "Prišlo je do napake med shranjevanjem zaznamka.",
     "Error" : "Napaka",
+    "Uncategorized" : "Neopredeljeno",
+    "Error parsing the import result" : "Napaka razčlenjevanja rezultata uvoza",
     "Import completed successfully." : "Uvoz je uspešno končan.",
+    "Do you really want to delete all your bookmarks?" : "Ali res želite izbrisati vse zaznamke?",
     "Set tags" : "Nastavitve oznak",
     "Failed to import one bookmark, because: " : "Uvoz izbranega zaznamka je spodletel:",
     "No file provided for import" : "Ni navedenih datotek za uvoz",
     "Unsupported file type for import" : "Nepodprta vrsta datoteke za uvoz",
     "A Bookmark manager for Nextcloud" : "Upravljalnik zaznamkov za Nextcloud",
+    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Program omogoča shranjevanje in urejanje zaznamkov priljubljenih spletnih strani in hkrati usklajevanje z različnimi napravami in brskalniki.\nNabor odjemalcev, ki so podprti s sistemom, je mogoče preveriti na: https://github.com/nextcloud/bookmarks#third-party-clients",
     "Add a bookmark" : "Dodaj zaznamek",
     "This URL is already bookmarked! Overwrite?" : "Ta naslov URL je že dodan med zaznamke. Ali ga želite prepisati?",
     "The title of the page" : "Naziv strani",
